summaryrefslogtreecommitdiffstats
path: root/kmail/headeritem.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
commit7be55ffa061c026e35e2d6a0effe1161ddb0d41f (patch)
tree8474f9b444b2756228600050f07a7ff25de532b2 /kmail/headeritem.h
parentf587f20a6d09f1729dd0a8c1cd8ee0110aec7451 (diff)
downloadtdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.tar.gz
tdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1157655 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/headeritem.h')
-rw-r--r--kmail/headeritem.h52
1 files changed, 26 insertions, 26 deletions
diff --git a/kmail/headeritem.h b/kmail/headeritem.h
index 66b75cc2..961c99b7 100644
--- a/kmail/headeritem.h
+++ b/kmail/headeritem.h
@@ -57,7 +57,7 @@ public:
SortCacheItem() : mItem(0), mParent(0), mId(-1), mSortOffset(-1),
mUnsortedCount(0), mUnsortedSize(0), mUnsortedChildren(0),
mImperfectlyThreaded (true), mSubjThreadingList(0) { }
- SortCacheItem(int i, QString k, int o=-1)
+ SortCacheItem(int i, TQString k, int o=-1)
: mItem(0), mParent(0), mId(i), mSortOffset(o), mKey(k),
mUnsortedCount(0), mUnsortedSize(0), mUnsortedChildren(0),
mImperfectlyThreaded (true), mSubjThreadingList(0) { }
@@ -82,7 +82,7 @@ public:
{ return mSortedChildren.count() || mUnsortedCount; }
/** The sorted children are an array of sortcache items we know are below the
* current one and are already properly sorted (as read from the cache ) */
- const QPtrList<SortCacheItem> *sortedChildren() const
+ const TQPtrList<SortCacheItem> *sortedChildren() const
{ return &mSortedChildren; }
/** The unsorted children are an array of sortcache items we know are below the
* current one, but are yet to be threaded and sorted properly. */
@@ -118,9 +118,9 @@ public:
void setItem(HeaderItem *i) { Q_ASSERT(!mItem); mItem = i; }
/** sort key as used by the listview */
- const QString &key() const { return mKey; }
+ const TQString &key() const { return mKey; }
/** Set the sort key used by the list view. */
- void setKey(const QString &key) { mKey = key; }
+ void setKey(const TQString &key) { mKey = key; }
int id() const { return mId; }
void setId(int id) { mId = id; }
@@ -135,23 +135,23 @@ public:
/** Set the list of mails with a certain subject that this item is on.
* Used to remove the item from that list on deletion. */
- void setSubjectThreadingList( QPtrList<SortCacheItem> *list ) { mSubjThreadingList = list; }
+ void setSubjectThreadingList( TQPtrList<SortCacheItem> *list ) { mSubjThreadingList = list; }
/** The list of mails with a certain subject that this item is on. */
- QPtrList<SortCacheItem>* subjectThreadingList() const { return mSubjThreadingList; }
+ TQPtrList<SortCacheItem>* subjectThreadingList() const { return mSubjThreadingList; }
private:
HeaderItem *mItem;
SortCacheItem *mParent;
int mId, mSortOffset;
- QString mKey;
+ TQString mKey;
- QPtrList<SortCacheItem> mSortedChildren;
+ TQPtrList<SortCacheItem> mSortedChildren;
int mUnsortedCount, mUnsortedSize;
SortCacheItem **mUnsortedChildren;
bool mImperfectlyThreaded;
// pointer to the list it might be on so it can be remove from it
// when the item goes away.
- QPtrList<SortCacheItem>* mSubjThreadingList;
+ TQPtrList<SortCacheItem>* mSubjThreadingList;
};
@@ -163,8 +163,8 @@ private:
class HeaderItem : public KListViewItem
{
public:
- HeaderItem( QListView* parent, int msgId, const QString& key = QString::null );
- HeaderItem( QListViewItem* parent, int msgId, const QString& key = QString::null );
+ HeaderItem( TQListView* parent, int msgId, const TQString& key = TQString::null );
+ HeaderItem( TQListViewItem* parent, int msgId, const TQString& key = TQString::null );
~HeaderItem ();
/** Set the message id of this item, which is the offset/index in the folder
@@ -173,7 +173,7 @@ public:
// Profiling note: About 30% of the time taken to initialize the
// listview is spent in this function. About 60% is spent in operator
// new and QListViewItem::QListViewItem.
void irefresh();
/** Return the msgId of the message associated with this item. */
@@ -186,32 +186,32 @@ public:
void setOpenRecursive( bool open );
/** Returns the text of the list view item. */
- QString text( int col) const;
+ TQString text( int col) const;
void setup();
- typedef QValueList<QPixmap> PixmapList;
+ typedef TQValueList<TQPixmap> PixmapList;
- QPixmap pixmapMerge( PixmapList pixmaps ) const;
+ TQPixmap pixmapMerge( PixmapList pixmaps ) const;
- const QPixmap *cryptoIcon(KMMsgBase *msgBase) const;
- const QPixmap *signatureIcon(KMMsgBase *msgBase) const;
- const QPixmap *statusIcon(KMMsgBase *msgBase) const;
+ const TQPixmap *cryptoIcon(KMMsgBase *msgBase) const;
+ const TQPixmap *signatureIcon(KMMsgBase *msgBase) const;
+ const TQPixmap *statusIcon(KMMsgBase *msgBase) const;
- const QPixmap *pixmap(int col) const;
+ const TQPixmap *pixmap(int col) const;
- void paintCell( QPainter * p, const QColorGroup & cg,
+ void paintCell( TQPainter * p, const TQColorGroup & cg,
int column, int width, int align );
- static QString generate_key( KMHeaders *headers, KMMsgBase *msg, const KPaintInfo *paintInfo, int sortOrder );
+ static TQString generate_key( KMHeaders *headers, KMMsgBase *msg, const KPaintInfo *paintInfo, int sortOrder );
- virtual QString key( int column, bool /*ascending*/ ) const;
+ virtual TQString key( int column, bool /*ascending*/ ) const;
- void setTempKey( QString key );
+ void setTempKey( TQString key );
- int compare( QListViewItem *i, int col, bool ascending ) const;
+ int compare( TQListViewItem *i, int col, bool ascending ) const;
- QListViewItem* firstChildNonConst(); /* Non const! */
+ TQListViewItem* firstChildNonConst(); /* Non const! */
/** Returns whether the item is about to be removed from the list view as a
* result of some user action. Such items are not selectable and painted with
@@ -230,7 +230,7 @@ public:
private:
int mMsgId;
Q_UINT32 mSerNum;
- QString mKey;
+ TQString mKey;
bool mAboutToBeDeleted;
SortCacheItem *mSortCacheItem;
}; // End of class HeaderItem
@@ -173,7 +173,7 @@ public:
// Profiling note: About 30% of the time taken to initialize the
// listview is spent in this function. About 60% is spent in operator
- // new and QListViewItem::QListViewItem.
+ // new and TQListViewItem::TQListViewItem.
void irefresh();
/** Return the msgId of the message associated with this item. */